@@ -87,15 +87,17 @@ class Device():
                             # Some attributes is picked from first switch in stack.                            
                             stack1 = PNPdevices['deviceInfo']['stackInfo']['stackMemberList'][0]
                             self.softwareVersion = stack1['softwareVersion']       
+
                 else:
                     self.id = PNPdevices['id']
-                    self.state = PNPdevices['state']
-                    self.hostname = PNPdevices['name']
-                    self.platform = PNPdevices['pid']
-                    self.softwareVersion = PNPdevices['softwareVersion']
-                    self.softwareType = PNPdevices['agentType']
+                    self.state = PNPdevices['deviceInfo']['state']
+                    self.hostname = PNPdevices['deviceInfo']['name']
+                    self.platform = PNPdevices['deviceInfo']['pid']
+                    self.softwareVersion = PNPdevices['deviceInfo']['imageVersion']
+                    self.softwareType = PNPdevices['deviceInfo']['agentType']
+
             except:
-                raise ezDNACError('device with serialNumber ' +
+                raise NotFound('device with serialNumber ' +
                                   str(self.serialNumber) + ' not found')
             try:
                 httpHeaders = PNPdevices['deviceInfo']['httpHeaders']
@@ -109,13 +111,16 @@ class Device():
         endpoint = f"network-device/{self.id}"
         response = restcall('GET', self.dnac, endpoint)['response']
 
-        self.serialNumber = response['serialNumber']
-        self.ip = response['managementIpAddress']
-        self.hostname = response['hostname']
-        self.platform = response['platformId']
-        self.softwareVersion = response['softwareVersion']
-        self.softwareType = response['softwareType']
-        self.collectionStatus = response['collectionStatus']
+        try:
+            self.serialNumber = response['serialNumber'].split(',')
+            self.ip = response['managementIpAddress']
+            self.hostname = response['hostname']
+            self.platform = response['platformId']
+            self.softwareVersion = response['softwareVersion']
+            self.softwareType = response['softwareType']
+            self.collectionStatus = response['collectionStatus']
+        except:
+            pass
 
         return None
 
@@ -335,14 +340,30 @@ class Device():
 
     def claimDevice(self, siteId, **kwargs):
         endpoint = "onboarding/pnp-device/site-claim"
-        
-        if 'template' in kwargs:
+        configParams = []
+
+        if 'payload' in kwargs:
+            payload = kwargs['payload']
+
+        elif 'template' in kwargs:
+            template = kwargs['template']
+            for key, value in template.params.items():
+                param = {"key": key, "value": value}
+                configParams.append(param)
+
             payload = {
                 "siteId": siteId,
                 "deviceId": self.id,
                 "type": "Default",
-                "imageInfo": {"imageId": "None", "skip": "true"},
-                "configInfo": {"configId": "", "configParameters": [kwargs['template'].params]}
+                "imageInfo": {
+                    "imageId": "None",
+                    "skip": True
+                },
+                "configInfo": {
+                    "saveToStartUp": True,
+                    "connLossRollBack": True,
+                    "configId": template.id,
+                    "configParameters": configParams}
             }
         else:
             payload = {
@@ -353,7 +374,7 @@ class Device():
                 "configInfo": {"configId": "", "configParameters": []}
             }
 
-        print(payload)
+        print(json.dumps(payload, indent=4))
         data = restcall('POST', self.dnac, endpoint, jsondata=payload)
         print(data)
         try:
