@@ -1,4 +1,3 @@
-import ezdnac.dnac
 import requests
 import json
 
@@ -29,18 +28,20 @@ def restcall(method, dnac, endpoint, **kwargs):
         headers = kwargs['headers']
     else:
         headers = {
-        'x-auth-token': dnac.authToken
+        'x-auth-token': dnac.authToken,
+        'Content-Type': 'application/json'
         }
 
     if 'baseurl' in kwargs:
         baseurl = kwargs['baseurl']
 
+    if method not in ['GET', 'PUT', 'POST', 'DELETE']:
+        return "Invalid rest method"
 
     url = f'https://{dnac.ip}:{dnac.port}{baseurl}{endpoint}'
-
     response = requests.request(method, url, headers=headers, data=data,
                                 json=jsondata, verify=dnac.verifySSL,
                                 timeout=dnac.timeout)
 
     jsondata = json.loads(response.text)
-    return jsondata
\ No newline at end of file
+    return jsondata
